@@ -3,8 +3,11 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
+use Exporter qw(
+    import
+);
 use Carp qw(
     croak
 );
@@ -16,10 +19,14 @@ use Params::Validate qw(
     SCALAR
 );
 
-our @EXPORT = qw(crypt verify crypt_with_hashinfo verify_with_hashinfo);
+our @EXPORT_OK = qw(
+    crypt
+    verify
+    crypt_with_hashinfo
+    verify_with_hashinfo
+);
 
 sub crypt {
-    my $self = shift;
 
     my %params = Params::Validate::validate(@_, {
         password        => { type => SCALAR },
@@ -57,7 +64,6 @@ sub crypt {
 }
 
 sub verify {
-    my $self = shift;
 
     my %params = Params::Validate::validate(@_, {
         password        => { type => SCALAR },
@@ -70,12 +76,11 @@ sub verify {
 
     my $pwhash = $params{password_hash};
     delete $params{password_hash};
-    my $calculated_pwhash = $self->crypt( %params );
+    my $calculated_pwhash = Crypt::Password::StretchedHash::crypt( %params );
     return ( $calculated_pwhash eq $pwhash );
 }
 
 sub crypt_with_hashinfo {
-    my $self = shift;
 
     my %params = Params::Validate::validate(@_, {
         password    => { type => SCALAR },
@@ -89,7 +94,7 @@ sub crypt_with_hashinfo {
 
     my $salt = $hash_info->salt;
 
-    my $pwhash = $self->crypt(
+    my $pwhash = Crypt::Password::StretchedHash::crypt(
         password        => $params{password},
         hash            => $hash_info->hash,
         salt            => $salt,
@@ -114,7 +119,6 @@ sub crypt_with_hashinfo {
 }
 
 sub verify_with_hashinfo {
-    my $self = shift;
 
     my %params = Params::Validate::validate(@_, {
         password        => { type => SCALAR },
@@ -151,7 +155,7 @@ sub verify_with_hashinfo {
     }
 
     # generate hashed password
-    my $expected_pwhash = $self->crypt(
+    my $expected_pwhash = Crypt::Password::StretchedHash::crypt(
         password        => $params{password},
         hash            => $hash_info->hash,
         salt            => $salt,
@@ -176,22 +180,23 @@ Crypt::Password::StretchedHash - simple library for password hashing and stretch
 This module provides Generation / Verification method for hashed password string.
 There are two methods to handle parameters simply.
 
-    use Test::More;
-    use Crypt::Password::StretchedHash;
+    use Crypt::Password::StretchedHash qw(
+        crypt
+        verify
+    );
     use Digest::SHA;
 
     # crypt
-    my $pwhash = Crypt::Password::StretchedHash->crypt(
+    my $pwhash = crypt(
         password        => q{password},
         hash            => Digest::SHA->new("sha256"),
         salt            => q{salt},
         stretch_count   => 5000,
         format          => q{base64},
     );
-    is($pwhash, q{4hvvzqZio+l9vGifQ7xF2+FKiyWRcb4lV3OSo9PsfUw=});
 
     # verify
-    my $result = Crypt::Password::StretchedHash->verify(
+    my $result = verify(
         password        => q{password},
         password_hash   => q{4hvvzqZio+l9vGifQ7xF2+FKiyWRcb4lV3OSo9PsfUw=},
         hash            => Digest::SHA->new("sha256"),
@@ -200,15 +205,15 @@ There are two methods to handle parameters simply.
         format          => q{base64},
     );
 
-    unless ( $result ) {
-        # password error
-    }
 
 if you use class of the hash information(Crypt::Passwoed::SaltedHash::HashInfo),
 there are two methods to generate/verify string for DB Store. 
 
     use Your::Password::HashInfo;
-    use Crypt::Password::StretchedHash;
+    use Crypt::Password::StretchedHash qw(
+        crypt_with_hashinfo
+        verify_with_hashinfo
+    );
     
     my $hash_info = Your::Password::HashInfo->new;
     # crypt
@@ -226,10 +231,6 @@ there are two methods to generate/verify string for DB Store.
         password_hash   => $pwhash_with_hashinfo,
         hash_info   => $hash_info,
     );
-    
-    unless ( $result ) {
-        # password error
-    }
 
 =head1 DESCRIPTION
 
